@@ -7,8 +7,8 @@
 #pragma once
 
 #include "index.h"
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 #include <KJob>
 
 /**
