@@ -9,14 +9,20 @@
 
 #include "akonadi_indexer_agent_debug.h"
 #include "collectionindexingjob.h"
-#include <AkonadiAgentBase/AgentBase>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/CollectionFetchScope>
-#include <AkonadiCore/IndexPolicyAttribute>
-#include <AkonadiCore/ServerManager>
+
+#include <Akonadi/AgentBase>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/IndexPolicyAttribute>
+#include <Akonadi/ServerManager>
+
 #include <KConfigGroup>
 #include <KLocalizedString>
+
 #include <QTimer>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 JobFactory::~JobFactory()
 {
@@ -41,7 +47,7 @@ Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config, const QShared
         m_jobFactory = QSharedPointer<JobFactory>(new JobFactory);
     }
     m_processTimer.setSingleShot(true);
-    m_processTimer.setInterval(100);
+    m_processTimer.setInterval(100ms);
     connect(&m_processTimer, &QTimer::timeout, this, &Scheduler::processNext);
 
     KConfigGroup cfg = m_config->group("General");
