@@ -14,12 +14,14 @@
 #include <QFile>
 #include <QTimer>
 
-#include <Collection>
-#include <CollectionFetchJob>
-#include <Item>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/Item>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <chrono>
 
+using namespace std::chrono_literals;
 class App : public QApplication
 {
     Q_OBJECT
@@ -61,7 +63,7 @@ App::App(int &argc, char **argv, int flags)
 
 void App::main()
 {
-    m_commitTimer.setInterval(1000);
+    m_commitTimer.setInterval(1s);
     connect(&m_commitTimer, &QTimer::timeout, this, &App::slotCommitTimerElapsed);
     m_commitTimer.start();
 
