@@ -4,7 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <errno.h>
+#include <cerrno>
 
 #include "akonadisearchdebugdialog.h"
 #include "akonadisearchdebugwidget.h"
@@ -35,7 +35,7 @@ AkonadiSearchDebugDialog::AkonadiSearchDebugDialog(QWidget *parent)
     setWindowTitle(QStringLiteral("Debug Akonadi Search"));
 
     auto mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     auto user1Button = new QPushButton;
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     // Don't translate it.
@@ -57,7 +57,7 @@ AkonadiSearchDebugDialog::~AkonadiSearchDebugDialog()
 
 void AkonadiSearchDebugDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "AkonadiSearchDebugDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "AkonadiSearchDebugDialog");
     const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -66,7 +66,7 @@ void AkonadiSearchDebugDialog::readConfig()
 
 void AkonadiSearchDebugDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "AkonadiSearchDebugDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "AkonadiSearchDebugDialog");
     group.writeEntry("Size", size());
 }
 
