@@ -5,7 +5,7 @@
 */
 
 #include "akonadisearchdebugsearchpathcombobox.h"
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/ServerManager>
 #include <QDir>
 #include <QStandardPaths>
 
