@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKONADISEARCHDEBUGSEARCHPATHCOMBOBOX_H
-#define AKONADISEARCHDEBUGSEARCHPATHCOMBOBOX_H
+#pragma once
 
 #include "search_debug_export.h"
 #include <QComboBox>
@@ -23,7 +22,7 @@ class AKONADI_SEARCH_DEBUG_EXPORT AkonadiSearchDebugSearchPathComboBox : public
 public:
     explicit AkonadiSearchDebugSearchPathComboBox(QWidget *parent = nullptr);
     enum SearchType { Contacts = 0, ContactCompleter, Emails, Notes, Calendars };
-    ~AkonadiSearchDebugSearchPathComboBox();
+    ~AkonadiSearchDebugSearchPathComboBox() override;
 
     QString searchPath();
 
@@ -36,4 +35,3 @@ private:
 };
 }
 }
-#endif // AKONADISEARCHDEBUGSEARCHPATHCOMBOBOX_H
