@@ -8,7 +8,7 @@
 
 #include "akonadisearchdebugsearchpathcombobox.h"
 #include "search_debug_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QWidget>
 class KLineEdit;
 class QPushButton;
@@ -25,7 +25,7 @@ class AKONADI_SEARCH_DEBUG_EXPORT AkonadiSearchDebugWidget : public QWidget
     Q_OBJECT
 public:
     explicit AkonadiSearchDebugWidget(QWidget *parent = nullptr);
-    ~AkonadiSearchDebugWidget();
+    ~AkonadiSearchDebugWidget() override;
 
     void setAkonadiId(Akonadi::Item::Id akonadiId);
     void setSearchType(AkonadiSearchDebugSearchPathComboBox::SearchType type);
