@@ -29,11 +29,11 @@ void AkonadiSearchDebugDialogTest::initTestCase()
 void AkonadiSearchDebugDialogTest::shouldHaveDefaultValue()
 {
     Akonadi::Search::AkonadiSearchDebugDialog dlg;
-    auto *debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
+    auto debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
     QVERIFY(debugWidget);
-    auto *editorWidget = debugWidget->findChild<QPlainTextEdit *>(QStringLiteral("plaintexteditor"));
+    auto editorWidget = debugWidget->findChild<QPlainTextEdit *>(QStringLiteral("plaintexteditor"));
     QVERIFY(editorWidget);
-    auto *lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
     QVERIFY(lineEdit);
     QVERIFY(lineEdit->text().isEmpty());
 }
@@ -41,9 +41,9 @@ void AkonadiSearchDebugDialogTest::shouldHaveDefaultValue()
 void AkonadiSearchDebugDialogTest::shouldFillLineEditWhenWeWantToSearchItem()
 {
     Akonadi::Search::AkonadiSearchDebugDialog dlg;
-    auto *debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
+    auto debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
     QVERIFY(debugWidget);
-    auto *lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
     QVERIFY(lineEdit);
     const int value = 42;
     const QString akonadiItem = QString::number(value);
