@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,7 +20,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *dlg = new Akonadi::Search::AkonadiSearchDebugDialog();
+    auto dlg = new Akonadi::Search::AkonadiSearchDebugDialog();
     dlg->resize(800, 600);
     dlg->show();
     app.exec();
