@@ -12,9 +12,11 @@
 #include "resultiterator.h"
 #include "search_pim_export.h"
 
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 #include <QStringList>
 
+#include <memory>
+
 namespace Akonadi
 {
 namespace Search
@@ -22,6 +24,8 @@ namespace Search
 /** PIM specific search API. */
 namespace PIM
 {
+class CollectionQueryPrivate;
+
 /** Collection query. */
 class AKONADI_SEARCH_PIM_EXPORT CollectionQuery : public Query
 {
@@ -55,8 +59,7 @@ public:
 
 private:
     //@cond PRIVATE
-    struct Private;
-    Private *const d;
+    std::unique_ptr<CollectionQueryPrivate> const d;
     //@endcond
 };
 }
