@@ -6,17 +6,23 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_CONTACTQUERY_H
-#define AKONADI_SEARCH_PIM_CONTACTQUERY_H
+#pragma once
 
-#include "search_pim_export.h"
 #include "query.h"
+#include "search_pim_export.h"
 
 #include <QString>
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+#include <memory>
+
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
+class ContactQueryPrivate;
+
 /**
  * Query for a list of contacts matching a criteria
  */
@@ -24,7 +30,7 @@ class AKONADI_SEARCH_PIM_EXPORT ContactQuery : public Query
 {
 public:
     ContactQuery();
-    ~ContactQuery();
+    ~ContactQuery() override;
 
     void matchName(const QString &name);
     void matchNickname(const QString &nick);
@@ -32,10 +38,7 @@ public:
     void matchUID(const QString &uid);
     void match(const QString &str);
 
-    enum MatchCriteria {
-        ExactMatch,
-        StartsWithMatch
-    };
+    enum MatchCriteria { ExactMatch, StartsWithMatch };
 
     void setMatchCriteria(MatchCriteria m);
     MatchCriteria matchCriteria() const;
@@ -46,11 +49,9 @@ public:
     void setLimit(int limit);
 
 private:
-    class Private;
-    Private *d;
+    std::unique_ptr<ContactQueryPrivate> const d;
 };
 }
 }
 }
 
-#endif // AKONADI_SEARCH_PIM_CONTACTQUERY_H
