@@ -11,15 +11,19 @@
 #include "query.h"
 #include "search_pim_export.h"
 
-#include <Collection>
+#include <Akonadi/Collection>
 #include <QStringList>
 
+#include <memory>
+
 namespace Akonadi
 {
 namespace Search
 {
 namespace PIM
 {
+class EmailQueryPrivate;
+
 /** Email query. */
 class AKONADI_SEARCH_PIM_EXPORT EmailQuery : public Query
 {
@@ -94,8 +98,7 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<EmailQueryPrivate> const d;
     //@endcond
 };
 }
