@@ -5,13 +5,14 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
-#ifndef INDEXEDITEMS_H
-#define INDEXEDITEMS_H
+#pragma once
 
 #include "search_pim_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QObject>
 
+#include <memory>
+
 namespace Akonadi
 {
 namespace Search
@@ -26,7 +27,7 @@ class AKONADI_SEARCH_PIM_EXPORT IndexedItems : public QObject
     Q_OBJECT
 public:
     explicit IndexedItems(QObject *parent = nullptr);
-    ~IndexedItems();
+    ~IndexedItems() override;
 
     void setOverrideDbPrefixPath(const QString &path);
 
@@ -43,9 +44,8 @@ public:
     QString contactIndexingPath() const;
 
 private:
-    IndexedItemsPrivate *const d;
+    std::unique_ptr<IndexedItemsPrivate> const d;
 };
 }
 }
 }
-#endif // INDEXEDITEMS_H
