@@ -12,12 +12,16 @@
 #include "search_pim_export.h"
 #include <QString>
 
+#include <memory>
+
 namespace Akonadi
 {
 namespace Search
 {
 namespace PIM
 {
+class NoteQueryPrivate;
+
 /**
  * Query for a list of contacts matching a criteria
  */
@@ -36,8 +40,7 @@ public:
     ResultIterator exec() override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<NoteQueryPrivate> const d;
 };
 }
 }
