@@ -6,19 +6,24 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_RESULT_ITERATOR_H
-#define AKONADI_SEARCH_PIM_RESULT_ITERATOR_H
+#pragma once
 
 #include "search_pim_export.h"
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+#include <memory>
+
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 class ContactQuery;
 class EmailQuery;
 class NoteQuery;
+class ResultIteratorPrivate;
 
 /** Result iterator. */
 class AKONADI_SEARCH_PIM_EXPORT ResultIterator
@@ -37,11 +42,9 @@ private:
     friend class NoteQuery;
     friend class CollectionQuery;
 
-    class Private;
-    Private *d;
+    std::unique_ptr<ResultIteratorPrivate> const d;
 };
 }
 }
 }
 
-#endif // AKONADI_SEARCH_PIM_RESULT_ITERATOR_H
