@@ -13,8 +13,8 @@
 #include <QDebug>
 #include <QTimer>
 
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include <KMime/Message>
 
