@@ -15,9 +15,9 @@
 #include <QSharedPointer>
 #include <QThread>
 
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/Session>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Session>
 
 #include <KContacts/Addressee>
 
@@ -111,7 +111,7 @@ void PIMContactsRunner::queryContacts(Plasma::RunnerContext &context, const QStr
         }
 
         if (contact.isEmpty()) {
-            qCDebug(AKONADI_KRUNNER_LOG) << "Corrupted index? Index referrs to an Item with an empty contact";
+            qCDebug(AKONADI_KRUNNER_LOG) << "Corrupted index? Index refers to an Item with an empty contact";
             continue;
         }
 
@@ -198,7 +198,8 @@ void PIMContactsRunner::queryAutocompleter(Plasma::RunnerContext &context, const
             match.setType(Plasma::QueryMatch::PossibleMatch);
         }
 
-        QString name, email;
+        QString name;
+        QString email;
         if (KEmailAddress::extractEmailAddressAndName(result, email, name)) {
             if (name.isEmpty()) {
                 match.setText(email);
