@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_XAPIANDATABASE_H
-#define AKONADI_SEARCH_XAPIANDATABASE_H
+#pragma once
 
 #include "search_xapian_export.h"
 #include <xapian.h>
@@ -68,7 +67,7 @@ private:
     Xapian::Database *m_db = nullptr;
     Xapian::WritableDatabase m_wDb;
 
-    typedef QPair<Xapian::docid, Xapian::Document> DocIdPair;
+    using DocIdPair = QPair<Xapian::docid, Xapian::Document>;
     QVector<DocIdPair> m_docsToAdd;
     QVector<uint> m_docsToRemove;
 
@@ -80,4 +79,3 @@ private:
 }
 }
 
-#endif // AKONADI_SEARCH_XAPIANDATABASE_H
