@@ -72,7 +72,7 @@ Xapian::Query makeQuery(const QString &string, int position, Xapian::Database *d
     QVector<Xapian::Query> queries;
     queries.reserve(topTerms.size());
 
-    for (const Term &term : qAsConst(topTerms)) {
+    for (const Term &term : std::as_const(topTerms)) {
         queries << Xapian::Query(term.t, 1, position);
     }
 
