@@ -5,16 +5,17 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_XAPIAN_QUERYPARSER_H
-#define AKONADI_SEARCH_XAPIAN_QUERYPARSER_H
+#pragma once
 
 #include <xapian.h>
 
-#include <QString>
 #include "search_xapian_export.h"
+#include <QString>
 
-namespace Akonadi {
-namespace Search {
+namespace Akonadi
+{
+namespace Search
+{
 /** Xapian query parser. */
 class AKONADI_SEARCH_XAPIAN_EXPORT XapianQueryParser
 {
@@ -37,9 +38,8 @@ public:
 
 private:
     Xapian::Database *m_db = nullptr;
-    bool m_autoExpand;
+    bool m_autoExpand = true;
 };
 }
 }
 
-#endif // AKONADI_SEARCH_XAPIAN_QUERYPARSER_H
